@@ -4,7 +4,7 @@ import yaml
 
 class FileSignatures:
     def __init__(self):
-        with open("Data/file_signatures.yaml", "r") as myfile:
+        with open("file_signatures.yaml", "r") as myfile:
             data = myfile.read()
             self.file_sigs = yaml.load(data, Loader=yaml.FullLoader)
 
